==> org.eclipse.wb.core.source_1.20.0.202505271655.jar: org/eclipse/wb/core/gef/policy/selection/LineSelectionEditPolicy.java <==
/*******************************************************************************
 * Copyright (c) 2011, 2023 Google, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.wb.core.gef.policy.selection;

import org.eclipse.wb.draw2d.Figure;
import org.eclipse.wb.draw2d.FigureUtils;
import org.eclipse.wb.draw2d.border.LineBorder;
import org.eclipse.wb.gef.core.EditPart;
import org.eclipse.wb.gef.graphical.handles.Handle;
import org.eclipse.wb.gef.graphical.policies.SelectionEditPolicy;

import org.eclipse.draw2d.AncestorListener;
import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.swt.graphics.Color;

import java.util.Collections;
import java.util.List;

/**
 * {@link SelectionEditPolicy} that has no {@link Handle}'s, just shows line around {@link EditPart}
 * .
 *
 * @author mitin_aa
 * @author scheglov_ke
 * @coverage core.gef.menu
 */
public class LineSelectionEditPolicy extends SelectionEditPolicy {
	private final Color m_lineColor;
	private Figure m_selectionFigure;
	private AncestorListener m_ancestorListener;

	////////////////////////////////////////////////////////////////////////////
	//
	// Constructor
	//
	////////////////////////////////////////////////////////////////////////////
	public LineSelectionEditPolicy() {
		this(ColorConstants.orange);
	}

	public LineSelectionEditPolicy(Color lineColor) {
		m_lineColor = lineColor;
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Handles
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	protected List<Handle> createSelectionHandles() {
		return Collections.emptyList();
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Selection
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	protected void showSelection() {
		hideSelection();
		m_selectionFigure = new Figure();
		m_selectionFigure.setBorder(new LineBorder(m_lineColor));
		updateFeedbackBounds();
		m_ancestorListener = new AncestorListener.Stub() {
			@Override
			public void ancestorMoved(IFigure ancestor) {
				updateFeedbackBounds();
			}
		};
		getHostFigure().addAncestorListener(m_ancestorListener);
		addFeedback(m_selectionFigure);
	}

	@Override
	protected void hideSelection() {
		if (m_selectionFigure != null) {
			getHostFigure().removeAncestorListener(m_ancestorListener);
			removeFeedback(m_selectionFigure);
			m_selectionFigure = null;
		}
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Feedbacks
	//
	////////////////////////////////////////////////////////////////////////////
	/**
	 * Updates feedback figure bounds in ancestor listener.
	 */
	private void updateFeedbackBounds() {
		Rectangle selectionBounds = getHostBounds().getExpanded(1, 1);
		FigureUtils.translateFigureToFigure(getHostFigure(), m_selectionFigure, selectionBounds);
		m_selectionFigure.setBounds(selectionBounds);
	}

	/**
	 * @return the bounds of {@link Figure} of host {@link EditPart}, in "bounds" coordinates.
	 */
	protected Rectangle getHostBounds() {
		return getHostFigure().getBounds();
	}
}

==> org.eclipse.wb.core.source_1.21.0.202508081944.jar: org/eclipse/wb/core/gef/policy/selection/LineSelectionEditPolicy.java <==
/*******************************************************************************
 * Copyright (c) 2011, 2025 Google, Inc. and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.wb.core.gef.policy.selection;

import org.eclipse.wb.draw2d.Figure;
import org.eclipse.wb.draw2d.FigureUtils;
import org.eclipse.wb.draw2d.border.LineBorder;
import org.eclipse.wb.gef.core.EditPart;
import org.eclipse.wb.gef.graphical.handles.Handle;
import org.eclipse.wb.gef.graphical.policies.SelectionEditPolicy;

import org.eclipse.draw2d.AncestorListener;
import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.swt.graphics.Color;

import java.util.Collections;
import java.util.List;

/**
 * {@link SelectionEditPolicy} that has no {@link Handle}'s, just shows line around {@link EditPart}
 * .
 *
 * @author mitin_aa
 * @author scheglov_ke
 * @coverage core.gef.menu
 */
public class LineSelectionEditPolicy extends SelectionEditPolicy {
	private final Color m_lineColor;
	private IFigure m_selectionFigure;
	private AncestorListener m_ancestorListener;

	////////////////////////////////////////////////////////////////////////////
	//
	// Constructor
	//
	////////////////////////////////////////////////////////////////////////////
	public LineSelectionEditPolicy() {
		this(ColorConstants.orange);
	}

	public LineSelectionEditPolicy(Color lineColor) {
		m_lineColor = lineColor;
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Handles
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	protected List<Handle> createSelectionHandles() {
		return Collections.emptyList();
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Selection
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	protected void showSelection() {
		hideSelection();
		m_selectionFigure = new Figure();
		m_selectionFigure.setBorder(new LineBorder(m_lineColor));
		updateFeedbackBounds();
		m_ancestorListener = new AncestorListener.Stub() {
			@Override
			public void ancestorMoved(IFigure ancestor) {
				updateFeedbackBounds();
			}
		};
		getHostFigure().addAncestorListener(m_ancestorListener);
		addFeedback(m_selectionFigure);
	}

	@Override
	protected void hideSelection() {
		if (m_selectionFigure != null) {
			getHostFigure().removeAncestorListener(m_ancestorListener);
			removeFeedback(m_selectionFigure);
			m_selectionFigure = null;
		}
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Feedbacks
	//
	////////////////////////////////////////////////////////////////////////////
	/**
	 * Updates feedback figure bounds in ancestor listener.
	 */
	private void updateFeedbackBounds() {
		Rectangle selectionBounds = getHostBounds().getExpanded(1, 1);
		FigureUtils.translateFigureToFigure(getHostFigure(), m_selectionFigure, selectionBounds);
		m_selectionFigure.setBounds(selectionBounds);
	}

	/**
	 * @return the bounds of {@link IFigure} of host {@link EditPart}, in "bounds" coordinates.
	 */
	protected Rectangle getHostBounds() {
		return getHostFigure().getBounds();
	}
}
